<?php

defined('_JEXEC') or die();

jimport( 'joomla.application.component.model' );

class GetMailingModelGetMailing extends JModel {

    /**
     * Model GetMailingModelGetMailing
     * Nesta classe é feito toda a manipulação necessária para apresentar o total dos registros, paginação,
     * busca e filtragem de dados na listagem de registros do GetMailing
     */

    var $_data;

    var $_total = null;

    var $_pagination = null;

    function __construct() {

        parent::__construct();

        global $mainframe, $option;

        // Captura o valor das variáveis responsáveis pela manipulação da paginação.
        $limit = $mainframe->getUserStateFromRequest('global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
        $limitstart = $mainframe->getUserStateFromRequest($option.'.limitstart', 'limitstart', 0, 'int');

        // Caso o valor da variável limit tenha sido mudado, ajusta de acordo com a limitstart
        $limitstart = ($limit != 0 ? (floor($limitstart / $limit) * $limit) : 0);

        $this->setState('limit', $limit);
        $this->setState('limitstart', $limitstart);
        
    }

    /**
     * Método responsável por capturar o total de registros
     * @access public
     * @return integer
     */
    function getTotal() {

        // Carrega todo o conteúdo
        if(empty($this->_total)) {

            $query = $this->_buildQuery();
            $this->_total = $this->_getListCount($query);

        }
        
        return $this->_total;

    }

    /**
     * Captura um objeto de Paginação
     * @access public
     * @return integer
     */
    function getPagination() {

        // Carrega o conteúdo
        if(empty($this->_pagination)) {

            jimport('joomla.html.pagination');
            $this->_pagination = new JPagination( $this->getTotal(), $this->getState('limitstart'), $this->getState('limit') );

        }

        return $this->_pagination;

    }

    /**
     * Retorna a query
     * @return retorna a query com as linhas do BD
     */
    function _buildQuery() {

        // Pega as cláusulas WHERE e ORDER BY para a query
        $where = $this->_buildContentWhere();
        $orderby = $this->_buildContentOrderBy();

        $query = "SELECT a.* FROM #__getmailing AS a $where $orderby";

        return $query;

    }

    /**
     * Query feita para gerar o conteúdo baseado na ordem setada
     * @return retorna a query com as linhas do BD
     */
    function _buildContentOrderBy() {

        global $mainframe, $option;

        $filter_order = $mainframe->getUserStateFromRequest($option.'filter_order', 'filter_order', 'a.id', 'cmd');

        //Verifica que ordem de filtragem foi setada
        $filter_order = ($filter_order == "a.ordering") ? "a.id" : $filter_order;

        $filter_order_Dir = $mainframe->getUserStateFromRequest($option.'filter_order_Dir', 'filter_order_Dir', 'desc', 'word');

        $orderby = "ORDER BY $filter_order $filter_order_Dir";

        return $orderby;

    }

    /**
     * Query feita para gerar o conteúdo baseado no que foi setado no WHERE
     * @return retorna a query com as linhas do BD
     */
    function _buildContentWhere() {

        global $mainframe, $option;
        
        $db =& JFactory::getDBO();

        $filter_state = $mainframe->getUserStateFromRequest($option.'filter_state', 'filter_state', '', 'word');

        $search = $mainframe->getUserStateFromRequest($option.'search', 'search', '', 'string');

        $search = JString::strtolower($search);

        $where = array();

        if($search) {

            $oi = '(LOWER(a.nome) LIKE ' . $db->Quote('%'.$db->getEscaped($search, true).'%', false);
            $oi .= ' OR LOWER(a.email) LIKE ' . $db->Quote('%'.$db->getEscaped($search, true).'%', false) . ')';

            $where[] = $oi;

        }

        if($filter_state) {

            if ($filter_state == 'P') {

                $where[] = 'a.published = 1';

            }

            elseif($filter_state == 'U') {

                $where[] = 'a.published = 0';

            }

        }

        $where = (count($where) ? ' WHERE '. implode(' AND ', $where) : '');

        return $where;

    }

    /**
     * Recupera os dados da tabela #__getmailing
     * @return Array com os dados
     */
    function getData() {

        if(empty($this->_data)) {

            $query = $this->_buildQuery();

            $this->_data = $this->_getList($query, $this->getState('limitstart'), $this->getState('limit'));

        }

        return $this->_data;

    }

}
?>